==> nextcloud-14.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/et_EE.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Esmase Käivituse Juhandaja",
    "Add your profile information! For example your email is needed to reset your password." : "Lisa oma profiili infot! Näiteks e-posti aadress on vajalik parooli lähtestamiseks.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisa oma profiili infot! Määra profiilipilt ja täisnimi, et sind oleks lihtsam ära tunda.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Lisa oma profiili infot! Lisa täisnimi, et sind oleks lihtsam ära tunda.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisa oma profiili infot! Määra profiilipilt, et sind oleks lihtsam ära tunda.",
    "Get the apps to sync your files" : "Hangi rakendusi failide sünkroniseerimiseks",
    "Desktop client" : "Töölaua klient",
    "Android app" : "Androidi rakendus",
    "iOS app" : "iOS-i rakendus",
    "Connect your desktop apps to %s" : "Ühenda oma töölaua rakendus %s",
    "Connect your calendar" : "Ühenda oma kalender",
    "Connect your contacts" : "Ühenda oma kontaktid",
    "Access files via WebDAV" : "Ligipääs WebDAV vahendusel",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Pääse oma failidele, kalendrile, kontaktidele, e-postile ja paljule muule ligi ja jaga neid igast seadmest enda seatud tingimustel",
    "Connect your Calendar" : "Ühenda oma kalender",
    "Connect your Contacts" : "Ühenda oma kontaktid",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "<a target=\"_blank\" href=\"%s\">Dokumentatsioonis</a> ja meie <a target=\"_blank\" href=\"%s\">veebilehel</a> on rohkem informatsiooni.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Kui sulle meeldib Nextcloud, siis <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\">soovita seda oma sõpradele</a> ja <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">löö kaasa</a>!",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Kui tahad projekti toetada {contributeopen}liitu arendusega{linkclose} või {contributeopen}levita infot{linkclose}!",
    "Show First Run Wizard again" : "Näita veelkord Esmase Käivituse Juhendajat"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/et_EE.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘+C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl+C.",
    "First run wizard" : "Esmase Käivituse Juhandaja",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisa oma profiili infot! Määra profiilipilt ja täisnimi, et sind oleks lihtsam ära tunda.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Lisa oma profiili infot! Lisa täisnimi, et sind oleks lihtsam ära tunda.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisa oma profiili infot! Määra profiilipilt, et sind oleks lihtsam ära tunda.",
    "About" : "Info",
    "Get the apps to sync your files" : "Hangi rakendusi failide sünkroniseerimiseks",
    "Desktop client" : "Töölaua klient",
    "iOS app" : "iOS-i rakendus",
    "Connect your desktop apps to %s" : "Ühenda oma töölaua rakendus %s",
    "Connect your calendar" : "Ühenda oma kalender",
    "Connect your contacts" : "Ühenda oma kontaktid",
    "Access files via WebDAV" : "Ligipääs WebDAV vahendusel",
    "A safe home for all your data" : "Turvaline koht sinu andmetele",
    "Server address" : "Serveri aadress",
    "Copy link" : "Kopeeri link"
},
"nplurals=2; plural=(n != 1);");
